@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20250923';
+our $VERSION = '5.20251022';
 our %utilities;
 
 sub utilities {
@@ -2196,6 +2196,13 @@ my %delta = (
         removed => {
         }
     },
+    5.043004 => {
+        delta_from => 5.043003,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
